#
# spec file for package policycoreutils
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define libaudit_ver     2.2
%define libsepol_ver     2.6
%define libsemanage_ver  2.6
%define libselinux_ver   2.6
%define sepolgen_ver     2.6
#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir %{_localstatedir}/adm/fillup-templates
%endif
Name:           policycoreutils
Version:        2.6
Release:        lp150.4.3.1
Summary:        SELinux policy core utilities
License:        GPL-2.0-or-later
Group:          Productivity/Security
Url:            https://github.com/SELinuxProject/selinux
Source:         https://raw.githubusercontent.com/wiki/SELinuxProject/selinux/files/releases/20161014/%{name}-%{version}.tar.gz
Source1:        https://raw.githubusercontent.com/wiki/SELinuxProject/selinux/files/releases/20161014/sepolgen-%{sepolgen_ver}.tar.gz
Source2:        system-config-selinux.png
Source3:        system-config-selinux.desktop
Source4:        system-config-selinux.pam
Source5:        system-config-selinux.console
Source6:        selinux-polgengui.desktop
Source7:        selinux-polgengui.console
Source8:        policycoreutils_man_ru2.tar.bz2
Patch4:         policycoreutils-initscript.patch
Patch5:         policycoreutils-pam-common.patch
Patch10:        loadpolicy_path.patch
Patch11:        CVE-2018-1063.patch
BuildRequires:  audit-devel >= %{libaudit_ver}
BuildRequires:  dbus-1-glib-devel
BuildRequires:  fdupes
BuildRequires:  gettext
BuildRequires:  hicolor-icon-theme
BuildRequires:  libcap-devel
BuildRequires:  libcap-ng-devel
BuildRequires:  libselinux-devel >= %{libselinux_ver}
BuildRequires:  libsemanage-devel >= %{libsemanage_ver}
BuildRequires:  libsepol-devel-static >= %{libsepol_ver}
BuildRequires:  pam-devel
# needed only for dir /usr/share/polkit-1 from policycoreutils-gui
BuildRequires:  polkit
BuildRequires:  python-devel
BuildRequires:  systemd-rpm-macros
BuildRequires:  update-desktop-files
Requires:       audit-libs-python
Requires:       checkpolicy
Requires:       gawk
Requires:       python-selinux
Requires:       policycoreutils-python
Requires:       rpm
Requires:       util-linux
# we need selinuxenabled
Requires(post): selinux-tools
Requires(pre):  %fillup_prereq
Requires(pre):  permissions
Recommends:     %{name}-lang
%{?systemd_requires}

%description
policycoreutils contains the policy core utilities that are required
for basic operation of a SELinux system.  These utilities include
load_policy to load policies, setfiles to label filesystems, newrole
to switch roles, and run_init to run %{_initddir} scripts in the proper
context.

(Security-enhanced Linux is a feature of the kernel and some
utilities that implement mandatory access control policies, such as
Type Enforcement, Role-based Access Control and Multi-Level
Security.)

%lang_package

%package python
Summary:        SELinux policy core python utilities
Group:          Productivity/Security
Requires:       audit-libs-python >= %{libaudit_ver}
Requires:       policycoreutils = %{version}
Requires:       python-ipy
Requires:       python-selinux >= %{libselinux_ver}
Requires:       python-semanage >= %{libsemanage_ver}
Requires:       python2-setools
Requires:       python-enum34
Requires:       python2-setuptools
Requires:       python-xml
Requires:       python-yum
Requires:       python2-networkx
Requires:       python2-selinux
Requires:       yum-metadata-parser

%description python
The policycoreutils-python package contains the management tools used to manage an SELinux environment.

%package sandbox
Summary:        SELinux sandbox utilities
Group:          Productivity/Security
Requires:       policycoreutils-python = %{version}
Requires:       xorg-x11-server-extra

%description sandbox
The sandbox package contains the scripts to create graphical sandboxes.

%package newrole
Summary:        The newrole application for RBAC/MLS
Group:          Productivity/Security
Requires:       policycoreutils = %{version}
Requires(pre):  permissions

%description newrole
RBAC/MLS policy machines require newrole as a way of changing the role
or level of a logged-in user.

%if 0%{?suse_version} != 1500
%package gui
Summary:        SELinux configuration GUI
Group:          Productivity/Security
Requires:       policycoreutils-python = %{version}
Requires:       python
Requires:       python-gnome
Requires:       python-gtk
Requires:       setools-console

%description gui
system-config-selinux is a utility for managing the SELinux environment.
%endif

%prep
%setup -q -a 1
%patch4
%patch5
%patch10 -p1
%patch11

%build
make %{?_smp_mflags} LSPP_PRIV=y LIBDIR="%{_libdir}" LIBEXECDIR="%{_libexecdir}" CFLAGS="%{optflags} -fPIE" LDFLAGS="-pie -Wl,-z,relro" all
make %{?_smp_mflags} -C sepolgen-%{sepolgen_ver} LSPP_PRIV=y LIBDIR="%{_libdir}" CFLAGS="%{optflags} -fPIE" LDFLAGS="-pie -Wl,-z,relro" all

%install
mkdir -p %{buildroot}%{_localstatedir}/lib/selinux
mkdir -p %{buildroot}%{_bindir}
mkdir -p %{buildroot}%{_sbindir}
mkdir -p %{buildroot}/sbin
mkdir -p %{buildroot}%{_mandir}/man1
mkdir -p %{buildroot}%{_mandir}/man8
mkdir -p %{buildroot}%{_sysconfdir}/pam.d
mkdir -p %{buildroot}%{_sysconfdir}/security/console.apps
make LSPP_PRIV=y DESTDIR=%{buildroot} LIBDIR="%{buildroot}%{_libdir}" LIBEXECDIR="%{buildroot}%{_libexecdir}" INITDIR="%{buildroot}%{_initddir}" install
make -C sepolgen-%{sepolgen_ver} DESTDIR=%{buildroot} LIBDIR="%{buildroot}%{_libdir}" install
install -D -m 644 %{SOURCE2} %{buildroot}%{_datadir}/pixmaps/system-config-selinux.png
# Don't install initscript if systemd is available
rm -r %{buildroot}%{_initddir}
ln -sf service %{buildroot}%{_sbindir}/rcrestorecond
install -m 644 %{SOURCE4} %{buildroot}%{_sysconfdir}/pam.d/system-config-selinux
install -m 644 %{SOURCE4} %{buildroot}%{_sysconfdir}/pam.d/selinux-polgengui
install -m 644 %{SOURCE5} %{buildroot}%{_sysconfdir}/security/console.apps/system-config-selinux
install -m 644 %{SOURCE7} %{buildroot}%{_sysconfdir}/security/console.apps/selinux-polgengui
tar -jxf %{SOURCE8} -C %{buildroot}/
rm -f %{buildroot}%{_mandir}/ru/man8/genhomedircon.8.gz
ln -sf consolehelper %{buildroot}%{_bindir}/system-config-selinux
ln -sf consolehelper %{buildroot}%{_bindir}/selinux-polgengui
mkdir -p %{buildroot}%{_fillupdir}/
mv %{buildroot}/%{_sysconfdir}/sysconfig/sandbox %{buildroot}%{_fillupdir}/sysconfig.sandbox
rmdir %{buildroot}/%{_sysconfdir}/sysconfig
%suse_update_desktop_file -i system-config-selinux System Security Settings
%suse_update_desktop_file -i sepolicy System Security Settings
%suse_update_desktop_file -i selinux-polgengui System Security Settings
%find_lang %{name}
%fdupes -s %{buildroot}/%{_datadir}
%if 0%{?suse_version} == 1500
rm %{buildroot}/etc/dbus-1/system.d/org.selinux.conf %{buildroot}/etc/pam.d/selinux-polgengui %{buildroot}/etc/pam.d/system-config-selinux %{buildroot}/etc/security/console.apps/selinux-polgengui %{buildroot}/etc/security/console.apps/system-config-selinux %{buildroot}/usr/bin/selinux-polgengui %{buildroot}/usr/bin/sepolgen %{buildroot}/usr/bin/system-config-selinux %{buildroot}/usr/share/applications/selinux-polgengui.desktop %{buildroot}/usr/share/applications/sepolicy.desktop %{buildroot}/usr/share/applications/system-config-selinux.desktop %{buildroot}/usr/share/icons/hicolor/16x16/apps/sepolicy.png %{buildroot}/usr/share/icons/hicolor/22x22/apps/sepolicy.png %{buildroot}/usr/share/icons/hicolor/24x24/apps/system-config-selinux.png %{buildroot}/usr/share/icons/hicolor/256x256/apps/sepolicy.png %{buildroot}/usr/share/icons/hicolor/32x32/apps/sepolicy.png %{buildroot}/usr/share/icons/hicolor/48x48/apps/sepolicy.png %{buildroot}/usr/share/man/man8/selinux-polgengui.8 %{buildroot}/usr/share/pixmaps/sepolicy.png %{buildroot}/usr/share/pixmaps/system-config-selinux.png %{buildroot}/usr/share/polkit-1/actions/org.selinux.config.policy %{buildroot}/usr/share/polkit-1/actions/org.selinux.policy %{buildroot}/usr/share/system-config-selinux/booleansPage.py %{buildroot}/usr/share/system-config-selinux/domainsPage.py %{buildroot}/usr/share/system-config-selinux/fcontextPage.py %{buildroot}/usr/share/system-config-selinux/html_util.py %{buildroot}/usr/share/system-config-selinux/loginsPage.py %{buildroot}/usr/share/system-config-selinux/mappingsPage.py %{buildroot}/usr/share/system-config-selinux/modulesPage.py %{buildroot}/usr/share/system-config-selinux/polgen.glade %{buildroot}/usr/share/system-config-selinux/polgengui.py %{buildroot}/usr/share/system-config-selinux/portsPage.py %{buildroot}/usr/share/system-config-selinux/selinux-polgengui.desktop %{buildroot}/usr/share/system-config-selinux/selinux_server.py %{buildroot}/usr/share/system-config-selinux/semanagePage.py %{buildroot}/usr/share/system-config-selinux/sepolicy.desktop %{buildroot}/usr/share/system-config-selinux/statusPage.py %{buildroot}/usr/share/system-config-selinux/system-config-selinux.desktop %{buildroot}/usr/share/system-config-selinux/system-config-selinux.glade %{buildroot}/usr/share/system-config-selinux/system-config-selinux.png %{buildroot}/usr/share/system-config-selinux/system-config-selinux.py %{buildroot}/usr/share/system-config-selinux/usersPage.py  %{buildroot}/usr/share/man/man8/system-config-selinux.8
%endif

%pre
%service_add_pre restorecond.service

%post
%service_add_post restorecond.service
%fillup_only

%preun
%service_del_preun restorecond.service

%postun
%service_del_postun restorecond.service

%post python
selinuxenabled && [ -f %{_datadir}/selinux/devel/include/build.conf ] && %{_bindir}/sepolgen-ifgen 2>/dev/null
exit 0

%post newrole
%set_permissions %{_bindir}/newrole

%verifyscript
%verify_permissions -e %{_bindir}/newrole

%files
/sbin/restorecon
/sbin/fixfiles
/sbin/setfiles
/sbin/load_policy
/sbin/restorecon_xattr
%{_sbindir}/genhomedircon
%{_sbindir}/load_policy
%{_sbindir}/restorecond
%{_sbindir}/setsebool
%{_sbindir}/semodule
%{_sbindir}/sestatus
%{_sbindir}/run_init
%{_sbindir}/open_init_pty
%{_bindir}/secon
%{_bindir}/semodule_deps
%{_bindir}/semodule_expand
%{_bindir}/semodule_link
%{_bindir}/semodule_package
%{_bindir}/semodule_unpackage
%attr(644,root,root) %{_unitdir}/restorecond.service
%config(noreplace) %{_sysconfdir}/pam.d/run_init
%config(noreplace) %{_sysconfdir}/sestatus.conf
%{_sbindir}/rcrestorecond
%config(noreplace) %{_sysconfdir}/selinux/restorecond.conf
%config(noreplace) %{_sysconfdir}/selinux/restorecond_user.conf
%{_sysconfdir}/xdg/autostart/restorecond.desktop
%dir %{_libexecdir}/selinux
%dir %{_libexecdir}/selinux/hll
%{_libexecdir}/selinux/hll/pp
%{_datadir}/dbus-1/services/org.selinux.Restorecond.service
%{_datadir}/dbus-1/system-services/org.selinux.service
# selinux-policy Requires: policycoreutils, so we own this set of directories and our files within them
%dir %{_mandir}/ru
%dir %{_mandir}/ru/man1
%dir %{_mandir}/ru/man8
%{_mandir}/man8/restorecon_xattr.8%{?ext_man}
%{_mandir}/man5/selinux_config.5%{?ext_man}
%{_mandir}/man5/sestatus.conf.5%{?ext_man}
%{_mandir}/man8/semodule_unpackage.8%{?ext_man}
%{_mandir}/man8/fixfiles.8%{?ext_man}
%{_mandir}/ru/man8/fixfiles.8%{?ext_man}
%{_mandir}/man8/load_policy.8%{?ext_man}
%{_mandir}/ru/man8/load_policy.8%{?ext_man}
%{_mandir}/man8/open_init_pty.8%{?ext_man}
%{_mandir}/ru/man8/open_init_pty.8%{?ext_man}
%{_mandir}/man8/restorecon.8%{?ext_man}
%{_mandir}/ru/man8/restorecon.8%{?ext_man}
%{_mandir}/man8/restorecond.8%{?ext_man}
%{_mandir}/ru/man8/restorecond.8%{?ext_man}
%{_mandir}/man8/run_init.8%{?ext_man}
%{_mandir}/ru/man8/run_init.8%{?ext_man}
%{_mandir}/man8/semodule.8%{?ext_man}
%{_mandir}/ru/man8/semodule.8%{?ext_man}
%{_mandir}/man8/semodule_deps.8%{?ext_man}
%{_mandir}/ru/man8/semodule_deps.8%{?ext_man}
%{_mandir}/man8/semodule_expand.8%{?ext_man}
%{_mandir}/ru/man8/semodule_expand.8%{?ext_man}
%{_mandir}/man8/semodule_link.8%{?ext_man}
%{_mandir}/ru/man8/semodule_link.8%{?ext_man}
%{_mandir}/man8/semodule_package.8%{?ext_man}
%{_mandir}/ru/man8/semodule_package.8%{?ext_man}
%{_mandir}/man8/sestatus.8%{?ext_man}
%{_mandir}/ru/man8/sestatus.8%{?ext_man}
%{_mandir}/man8/setfiles.8%{?ext_man}
%{_mandir}/ru/man8/setfiles.8%{?ext_man}
%{_mandir}/man8/setsebool.8%{?ext_man}
%{_mandir}/ru/man8/setsebool.8%{?ext_man}
%{_mandir}/man1/secon.1%{?ext_man}
%{_mandir}/ru/man1/secon.1%{?ext_man}
%{_mandir}/man8/genhomedircon.8%{?ext_man}

%files lang -f %{name}.lang

%files python
%{_sbindir}/semanage
%{_bindir}/audit2allow
%{_bindir}/audit2why
%{_bindir}/chcat
%{_bindir}/sandbox
%{_bindir}/sepolicy
%{_bindir}/sepolgen-ifgen
%{_bindir}/sepolgen-ifgen-attr-helper
%{python_sitearch}/seobject.py*
%{python_sitearch}/sepolgen
%{_prefix}/lib*/python2.7/site-packages/sepolicy
%{_prefix}/lib*/python2.7/site-packages/sepolicy*.egg-info
%dir %{_localstatedir}/lib/sepolgen
%dir %{_localstatedir}/lib/selinux
%{_localstatedir}/lib/sepolgen/perm_map
%{_mandir}/man1/audit2allow.1%{?ext_man}
%{_mandir}/ru/man1/audit2allow.1%{?ext_man}
%{_mandir}/man1/audit2why.1%{?ext_man}
%{_mandir}/man8/chcat.8%{?ext_man}
%{_mandir}/ru/man8/chcat.8%{?ext_man}
%{_mandir}/man8/sandbox.8%{?ext_man}
%{_mandir}/man5/sandbox*
%{_mandir}/man8/semanage*.8%{?ext_man}
%{_mandir}/man8/sepolicy*.8%{?ext_man}
%{_mandir}/man8/sepolgen.8%{?ext_man}
%{_mandir}/ru/man8/semanage.8%{?ext_man}
%{_datadir}/bash-completion/completions/semanage
%{_datadir}/bash-completion/completions/sepolicy
%{_datadir}/bash-completion/completions/setsebool

%files sandbox
%attr(0755,root,root) %{_sbindir}/seunshare
%dir %{_datadir}/sandbox
%{_datadir}/sandbox/sandboxX.sh
%{_datadir}/sandbox/start
%{_fillupdir}/sysconfig.sandbox
%{_mandir}/man8/seunshare.8%{?ext_man}

%files newrole
%verify(not mode) %attr(0755,root,root) %{_bindir}/newrole
%{_mandir}/man1/newrole.1%{?ext_man}
%config(noreplace) %{_sysconfdir}/pam.d/newrole

%if 0%{?suse_version} != 1500
%files gui
%{_bindir}/system-config-selinux
%{_bindir}/selinux-polgengui
%{_datadir}/applications/system-config-selinux.desktop
%{_datadir}/system-config-selinux/system-config-selinux.desktop
%{_bindir}/sepolgen
%{_datadir}/applications/selinux-polgengui.desktop
%{_datadir}/applications/sepolicy.desktop
%{_datadir}/system-config-selinux/selinux-polgengui.desktop
%{_datadir}/system-config-selinux/sepolicy.desktop
#%dir %{_datadir}/icons
#%dir %{_datadir}/icons/hicolor
#%dir %{_datadir}/icons/hicolor/24x24
#%dir %{_datadir}/icons/hicolor/24x24/apps
%{_datadir}/icons/hicolor/24x24/apps/system-config-selinux.png
%{_datadir}/icons/hicolor/16x16/apps/sepolicy.png
%{_datadir}/icons/hicolor/22x22/apps/sepolicy.png
%{_datadir}/icons/hicolor/256x256/apps/sepolicy.png
%{_datadir}/icons/hicolor/32x32/apps/sepolicy.png
%{_datadir}/icons/hicolor/48x48/apps/sepolicy.png
%{_datadir}/pixmaps/sepolicy.png
%{_datadir}/pixmaps/system-config-selinux.png
%{_datadir}/polkit-1/actions/org.selinux.config.policy
%{_datadir}/polkit-1/actions/org.selinux.policy
%dir %{_datadir}/system-config-selinux
#%dir %{_datadir}/system-config-selinux/templates
%{_datadir}/system-config-selinux/system-config-selinux.png
%{_datadir}/system-config-selinux/*.py*
#%{_datadir}/system-config-selinux/selinux.tbl
%{_datadir}/system-config-selinux/*.glade
%{_mandir}/man8/selinux-polgengui.8%{?ext_man}
%{_mandir}/man8/system-config-selinux.8%{?ext_man}
#%%{_datadir}/system-config-selinux/templates/*.py*
%config(noreplace) %{_sysconfdir}/dbus-1/system.d/org.selinux.conf
%config(noreplace) %{_sysconfdir}/pam.d/system-config-selinux
%config(noreplace) %{_sysconfdir}/pam.d/selinux-polgengui
%dir %{_sysconfdir}/security/console.apps
%config(noreplace) %{_sysconfdir}/security/console.apps/selinux-polgengui
%config(noreplace) %{_sysconfdir}/security/console.apps/system-config-selinux
%endif

%changelog
* Wed Mar 27 2019 jsegitz@suse.com
- Add a Requires for policycoreutils-python to policycoreutils, so
  that the expected binaries are present (bsc#1130097)
- Add Requires for python2-setools, python-enum34, python2-setuptools
  and python2-selinux to policycoreutils-python to ensure that it has
  all dependencies met
* Thu Mar 21 2019 jsegitz@suse.com
- Add Requires: for policycoreutils-python. policycoreutils-python
  contains binaries necessary for SELinux administration. Packaging
  is suboptimal here, it's already changed in newer versions. For
  now we we just require it to ensure users have the binaries they
  expect (bsc#1130097)
* Thu Apr 26 2018 jsegitz@suse.com
- SLE 15 doesn't have the necessary files for policycoreutils-gui,
  don't build it there
* Wed Apr 25 2018 jsegitz@suse.com
- Drop the requirement for selinux-policy for the gui tools.
* Tue Mar 27 2018 tchvatal@suse.com
- Drop SLE11 support, needs the audit that is not present on SLE11
- Fix service link to actually work on current releases
- Drop SUSE_ASNEEDED=0 as it seems to build fine without it
- Do not depend on systemd, just systemd-rpm-macros
* Wed Mar 21 2018 jsegitz@suse.com
- Added CVE-2018-1063.patch to prevent chcon from following symlinks in
  /tmp, /var/tmp, /var/run and /var/lib/debug (bsc#1083624, CVE-2018-1063)
* Tue Mar 20 2018 jsegitz@suse.com
- Remove BuildRequires for libcgroup-devel (bsc#1085837)
* Thu Dec 21 2017 jsegitz@suse.com
- Removed BuildRequires for setools-devel and added new
  runtime requirement for python2-networkx
* Mon Nov 27 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Fri Nov 24 2017 jsegitz@suse.com
- Update to policycoreutils version 2.6. Notable changes:
  * setfiles: reverse the sense of -D option
  * sandbox: Use dbus-run-session instead of dbus-launch when available
  * setfiles: Utility to find security.restorecon_last entries
  * setfiles: Add option to stop setting the digest
  * hll/pp: Change warning for module name not matching filename to match new behavior
  * sepolicy: convert to setools4
  * sandbox: create a new session for sandboxed processes
  * sandbox: do not try to setup directories without -X or -M
  * sandbox: do not run xmodmap in a new X session
  * sandbox: fix file labels on copied files
  * semanage: Fix semanage fcontext -D
  * semanage: Default serange to "s0" for port modify
  * semanage: Use socket.getprotobyname for protocol
  * semanage: Add auditing of changes in records
  * Improve compatibility with Python 3
  * Update sandbox types in sandbox manual
  * hll/pp: Warn if module name different than output filename
- Update to sepolgen version 2.6. Notable changes:
  * Add support for TYPEBOUNDS statement in INTERFACE policy files
- Dropped CVE-2016-7545_sandbox_escape.patch
* Mon Dec 19 2016 jsegitz@novell.com
- Added CVE-2016-7545_sandbox_escape.patch to fix CVE-2016-7545, bsc#1000998
  Sandboxed session could have escaped to the parent session
* Sat Jul 23 2016 jengelh@inai.de
- Trim description in line with other selinux packages
* Thu Jul 14 2016 jsegitz@novell.com
- Changes submitted by MargueriteSu:
  Update to version 2.5
  * sepolicy: Do not overwrite CFLAGS, from Nicolas Iooss.
  * sepolicy: Rename policy global variable conflict, from Nicolas Iooss.
  * newrole: Add missing defined in #if, from Nicolas Iooss.
  * newrole: Add description of missing parameter -p in newrole man page, from Lukas Vrabec.
  * secon: Add missing descriptions for --*-key params in secon man page, from Lukas Vrabec
  * semanage: List reserve_port_t in semanage port -l, from Petr Lautrbach.
  * chcat: Add a fallback in case os.getlogin() returns nothing, from Laurent Bigonville.
  * semanage: fix 'semanage permissions -l' subcommand, from Petr Lautrbach.
  * semanage: replace string.join() with str.join(), from Petr Lautrbach.
  * Man page warning fixes, from Ville Skyttä.
  * sandbox: Fix sandbox to propagate specified MCS/MLS Security Level, from Miroslav Grepl.
  * semanage: Require at least one argument for 'semanage permissive -d', from Petr Lautrbach.
  * sepolicy: Improve sepolicy command line interface, from Petr Lautrbach.
  * audit2allow/why: ignore setlocale errors, from Petr Lautrbach.
  * semodule: Add --extract/-E, --cil/-c, and --hll/-H to extract modules, from Yuli Khodorkovskiy.
  * audit2allow: Comment constraint rules in output, from Miroslav Grepl via Petr Lautrbach.
  * Fix PEP8 issues, from Jason Zaman.
  * semanage: fix moduleRecords deleteall method, from Stephen Smalley.
  * Improve compatibility with Python 3, from Michal Srb.
  * semanage: Set self.sename to sename after calling semanage_seuser_set_sename(), from Laurent Bigonville.
  * semanage: Fix typo in semanage args for minimium policy store, from Petr Lautrbach.
  * sepolicy: Only invoke RPM on RPM-enabled Linux distributions, from Sven Vermeulen.
  * mcstransd: don't reinvent getpeercon, from Stephen Smalley.
  * setfiles/restorecon: fix -r/-R option, from Petr Lautrbach.
  * org.selinux.policy: Require auth_admin_keep for all actions, from Stephen Smalley.
  * hll: Move core functions of pp to libsepol, from James Carter
  * run_init: Use a ring buffer in open_init_pty, from Jason Zaman.
  * run_init: fix open_init_pty availability check, from Nicolas Iooss.
  * Widen Xen IOMEM context entries, from Daniel De Graaf.
  * Fix -Wformat errors with gcc-5.0.0, from Petr Lautrbach.
  * Fixed typo/grammatical error, from Christopher Peterson.
  * Fix typo in semanage-port man page, from Andrew Spiers.
  Update to version 2.4
  * Fix bugs found by hardened gcc flags, from Nicolas Iooss.
  * Improve support for building with different versions of python from
    Nicolas Iooss.
  * Ensure XDG_RUNTIME_DIR is passed through to the sandbox in seunshare,
    from Dan Walsh
  * Remove cgroups from sandbox, from Dan Walsh
  * Try to use setcurrent before setexec in seunshare, from Andy Lutomirski
  * Stop using the now deprecated flask.h and av_permissions.h, from Stephen Smalley
  * Add a store root path in semodule, from Yuli Khodorkovskiy
  * Add a flag to ignore cached CIL files and recompile HLL modules, from
    Yuli Khodorkovskiy
  * Add and install HLL compiler for policy packages to CIL. The compiler is
    installed in /var/libexec/selinux/hll/ by default, from Steve Lawrence
  * Fixes to pp compiler to better support roles and type attributes, from
    Yuli Khodorkovskiy
  * Deprecate base/upgrade/version in semodule. Calling these commands will
    now call --install on the backend, from Yuli Khodorkovskiy
  * Add ability to install modules with a specified priority, from Caleb
    Case
  * Use /tmp for permissive module creation, by Caleb Case
  * Update semanage to use new source policy infrastructure, from Jason Dana
  * Add RuntimeDirectory to mcstrans systemd unit file, from Laurent
    Bigonville
* Wed Nov  5 2014 jsegitz@novell.com
- added Requires: python-yum, yum-metadata-parser to fix sepolicy
  (bnc#903841)
* Mon Sep  8 2014 jsegitz@suse.com
- removed execute permission from systemd unit file
* Sun May 18 2014 crrodriguez@opensuse.org
- Version 2.3
  sepolgen: Add back attributes flag to fix exception crash from Dan Walsh.
  (drop policycoreutils-sepolgen_missing_attributes.patch)
  * Add -P semodule option to man page from Dan Walsh.
  * selinux_current_policy_path will return none on a disabled SELinux system
  * Add new icons for sepolicy gui from Dan Walsh.
  * Only return writeable files that are enabled from Dan Walsh.
  * Add domain to short list of domains, when -t and -d from Dan Walsh.
  * Fix up desktop files to match current standards from Dan Walsh.
  * Add support to return sensitivities and categories for python from Dan Walsh.
  * Cleanup whitespace from Dan Walsh.
  * Add message to tell user to install sandbox policy from Dan Walsh.
  * Add systemd unit file for mcstrans from Laurent Bigonville.
  * Improve restorecond systemd unit file from Laurent Bigonville.
  * Minor man pages improvements from Laurent Bigonville.
  * Ignore selevel/serange if MLS is disabled from Sven Vermeulen.
  * Revert automatic setting of serange and seuser in seobject; was breaking non-MLS systems.
  * Apply polkit check on all dbus interfaces and restrict to active user from Dan Walsh.
  * Fix typo in sepolicy gui dbus.relabel_on_boot call from Dan Walsh.
  * Remove import policycoreutils.default_encoding_utf8 from semanage from Dan Walsh.
  * Make yum/extract_rpms optional for sepolicy generate from Dan Walsh.
  * Add test suite for audit2allow and sepolgen-ifgen from Dan Walsh.
* Fri Dec 13 2013 vcizek@suse.com
- sepolgen: add back attributes
  * fixes build of selinux-policy
  * policycoreutils-sepolgen_missing_attributes.patch
* Mon Dec  9 2013 vcizek@suse.com
- fix issues which prevented accepting to Factory
  * mention the dropped patches (merged upstream):
  - policycoreutils-rhat.patch
  - policycoreutils-sepolgen.patch
* Thu Oct 31 2013 p.drouand@gmail.com
- update to version 2.2
  * Properly build the swig exception file
  * Fix man pages
  * Support overriding PATH and INITDIR in Makefile
  * Fix LDFLAGS usage
  * Fix init_policy warning
  * Fix semanage logging
  * Open newrole stdin as read/write
  * Fix sepolicy transition
  * Support overriding CFLAGS
  * Create correct man directory for run_init
  * restorecon GLOB_BRACE change
  * Extend audit2why to report additional constraint information.
  * Catch IOError errors within audit2allow
  * semanage export/import fixes
  * Improve setfiles progress reporting
  * Document setfiles -o option in usage
  * Change setfiles to always return -1 on failure
  * Improve setsebool error r eporting
  * Major overhaul of gui
  * Fix sepolicy handling of non-MLS policy
  * Support returning type aliases
  * Add sepolicy tests
  * Add org.selinux.config.policy
  * Improve range and user input checking by semanage
  * Prevent source or target arguments that end with / for substitutions
  * Allow use of <<none>> for semanage fcontext
  * Report customized user levels
  * Support deleteall for restoring disabled modules
  * Improve semanage error reporting
  * Only list disabled modules for module locallist
  * Fix logging
  * Define new constants for file type character codes
  * Improve bash completions
  * Convert semanage to argparse
  * Add semanage tests
  * Split semanage man pages
  * Move bash completion scripts
  * Replace genhomedircon script with a link to semodule
  * Fix fixfiles
  * Add support for systemd service for restorecon
  * Spelling corrections
  * Improve sandbox support for home dir symlinks and file caps
  * Switch sandbox to openbox window manager
  * Coalesce audit2why and audit2allow
  * Change audit2allow to append to output file
  * Update translations
  * Change audit2why to use selinux_current_policy_path
- Update sepolgen to version 1.2
  * Return additional constraint information.
  * Fix bug in calls to attributes
  * Add support for filename transitions
  * Fix sepolgen tests
- Remove restorecond.service; use upstream service file
- Don't provide support for sysvinit and systemd on a same system
  Use either one or the other
* Thu Jun 27 2013 vcizek@suse.com
- change the source url to the official release tarballs
* Wed Apr  3 2013 vcizek@suse.com
- fixed source url
- removed old tarball
* Fri Mar 29 2013 vcizek@suse.com
- update to 2.1.14
  * setfiles: estimate percent progress
  * load_policy: make link at the destination directory
  * Rebuild polgen.glade with glade-3
  * sepolicy: new command to unite small utilities
  * sepolicy: Update Makefiles and po files
  * sandbox: use sepolicy to look for sandbox_t
  * gui: switch to use sepolicy
  * gui: sepolgen: use sepolicy to generate
  * semanage: use sepolicy for boolean dictionary
  * add po file configuration information
  * po: stop running update-po on all
  * semanage: seobject verify policy types before allowing you to assign them.
  * gui: Start using Popen, instead of os.spawnl
  * sandbox: Copy /var/tmp to /tmp as they are the same inside
  * qualifier to shred content
  * semanage: Fix handling of boolean_sub names when using the -F flag
  * semanage: man: roles instead of role
  * gui: system-config-selinux: Catch no DISPLAY= error
  * setfiles: print error if no default label found
  * semanage: list logins file entries in semanage login -l
  * semanage: good error message is sepolgen python module missing
  * gui: system-config-selinux: do not use lokkit
  * secon: add support for setrans color information in prompt output
  * restorecond: remove /etc/mtab from default list
  * gui: If you are not able to read enforcemode set it to False
  * genhomedircon: regenerate genhomedircon more often
  * restorecond: Add /etc/udpatedb.conf to restorecond.conf
  * genhomedircon generation to allow spec file to pass in SEMODULE_PATH
  * fixfiles: relabel only after specific date
  * po: update translations
  * sandbox: seunshare: do not reassign realloc value
  * seunshare: do checking on setfsuid
  * sestatus: rewrite to shut up coverity
- removed policycoreutils-glibc217.patch (upstream fix)
- added patches:
  * policycoreutils-rhat.patch
  * policycoreutils-sepolgen.patch
  * loadpolicy_path.patch
* Wed Jan 30 2013 vcizek@suse.com
- update to 2.1.13
  - drop policycoreutils-po.patch.bz2 (updated upstream)
  - drop policycoreutils-gui.patch.bz2 (added to upstream)
  - drop sandbox init scripts (shouldn't be needed anymore)
  - numerous other changes
* Tue Dec 11 2012 vcizek@suse.com
- added service unit for restorecond
* Wed Dec  5 2012 vcizek@suse.com
- semanage needs python-xml and python-ipy to run
* Sat Nov 17 2012 aj@suse.de
- Fix compilation with glibc 2.17 (add patch policycoreutils-glibc217.patch
  extracted from Fedora)
* Tue Aug  7 2012 meissner@suse.com
- updated policycoreutils to 2.1.10
  - adapated patches
- updated sepolgen to 1.1.5
* Tue Feb 14 2012 mvyskocil@suse.cz
- fix seceral rpmlint errors and warnings
  * use /var/adm/fillup-template for sandbox
  * don't use /var/lock/subsys in any of init script
  * use set_permissions macro and add correct Requires(pre)
  * fix the languages to new -lang package
  * fix policycoreutils-sandbox Group
  * remove runlevel 4 from inint scripts
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Mon Mar 14 2011 prusnak@opensuse.org
- updated to 2.0.85
  * changes too numerous to list
* Fri Feb  4 2011 toddrme2178@gmail.com
- fix a typo in the package group
* Fri Jun  4 2010 prusnak@opensuse.org
- remove usermode-gtk from Requires of -gui subpackage
* Fri May  7 2010 meissner@suse.de
- remove incorrect and unnecessary rpmlintrc.
* Mon Mar 22 2010 prusnak@suse.cz
- fix build by moving _GNU_SOURCE define (gnusource.patch), thx darix
* Thu Feb 25 2010 prusnak@suse.cz
- updated to 2.0.79
  * changes too numerous to list
* Wed Jul 15 2009 prusnak@suse.cz
- disable Requires usermode-gtk
* Fri Jun 19 2009 prusnak@suse.cz
- added libsepol-static-devel to BuildRequires
* Wed May 27 2009 prusnak@suse.cz
- updated to 2.0.62
  * Add btrfs to fixfiles from Dan Walsh.
  * Remove restorecond error for matching globs with multiple hard links
    and fix some error messages from Dan Walsh.
  * Make removing a non-existant module a warning rather than an error
    from Dan Walsh.
  * Man page fixes from Dan Walsh.
* Wed Feb 11 2009 ro@suse.de
- use sr@latin instead of sr@Latn
* Wed Jan 14 2009 prusnak@suse.cz
- updated to 2.0.61
  * semanage: use semanage_mls_enabled() from Stephen Smalley
  * fix error checking in restorecond, for inotify_add_watch
  * change md5 to hashlib.md5 in sepolgen
  * fix Japanese translations
  * fix audit2allow man page
  * don't error out when removing a non existing module
  * chcat: cut categories at arbitrary point (25) from Dan Walsh
  * semodule: use new interfaces in libsemanage for compressed
    files from Dan Walsh
  * audit2allow: string changes for usage
* Mon Dec  1 2008 prusnak@suse.cz
- updated to 2.0.59
  * Fix text in newrole
  * Fix revertbutton on booleans page in system-config-selinux
  * Fix system-config-selinux booleanspage throwing and exception
  * Allow addition of local modifications of fcontext policy
  * Handle selinux disabled correctly
  * Handle manipulation of fcontext file correctly
  * Fix traceback in audit2why
* Mon Nov 10 2008 ro@suse.de
- package "newrole" with permissions matching
  "secure" permissions mode
* Fri Nov  7 2008 ro@suse.de
- buildfix: prevent regeneration of policycoreutils.pot
* Fri Oct 31 2008 prusnak@suse.cz
- use permissions for newrole
* Mon Oct 20 2008 prusnak@suse.cz
- updated to 2.0.57
  * Update po files from Dan Walsh.
- updated to 2.0.56
  * fixfiles will now remove all files in /tmp and will check for
    unlabeled_t in /tmp and /var/tmp from Dan Walsh.
  * add glob support to restorecond from Dan Walsh.
  * allow semanage to handle multi-line commands in a single transaction
    from Dan Walsh.
* Mon Sep  8 2008 prusnak@suse.cz
- fix scriptlets
* Tue Sep  2 2008 prusnak@suse.cz
- updated to 2.0.55
  * Merged semanage node support from Christian Kuester.
- updated to 2.0.54
  * Add support for boolean files and group support for seusers from Dan Walsh.
  * Ensure that setfiles -p output is newline terminated from Russell Coker.
- updated to 2.0.53
  * Change setfiles to validate all file_contexts files when using -c from Stephen Smalley.
- updated sepolgen to 1.0.13
  * Only append s0 suffix if MLS is enabled from Karl MacMillan.
- added missing preun/post/postun scriptlets
* Sun Aug  3 2008 ro@suse.de
- add directory to filelist to fix build
* Tue Jul 15 2008 prusnak@suse.cz
- initial version 2.0.52
  * based on Fedora package by Dan Walsh <dwalsh@redhat.com>
